@@ -12,7 +12,7 @@ var xonshInit string
 func (f Features) Xonsh() Code {
 	switch f {
 	case Upgrade:
-		return "@(_omp_executable) upgrade"
+		return "@(_omp_executable) upgrade --auto"
 	case Notice:
 		return "@(_omp_executable) notice"
 	case PromptMark, RPrompt, PoshGit, Azure, LineError, Jobs, Tooltips, Transient, CursorPositioning, FTCSMarks, Async:
